==> libreoffice-5.2.3.3.tar.xz: libreoffice-5.2.3.3/sal/rtl/rtl_process.cxx <==
/* -*- Mode: C++; tab-width: 4; indent-tabs-mode: nil; c-basic-offset: 4 -*- */
/*
 * This file is part of the LibreOffice project.
 *
 * This Source Code Form is subject to the terms of the Mozilla Public
 * License, v. 2.0. If a copy of the MPL was not distributed with this
 * file, You can obtain one at http://mozilla.org/MPL/2.0/.
 *
 * This file incorporates work covered by the following license notice:
 *
 *   Licensed to the Apache Software Foundation (ASF) under one or more
 *   contributor license agreements. See the NOTICE file distributed
 *   with this work for additional information regarding copyright
 *   ownership. The ASF licenses this file to you under the Apache
 *   License, Version 2.0 (the "License"); you may not use this file
 *   except in compliance with the License. You may obtain a copy of
 *   the License at http://www.apache.org/licenses/LICENSE-2.0 .
 */

#include "sal/config.h"

#include <cstring>

#include "rtl/instance.hxx"
#include "rtl/process.h"
#include "rtl/uuid.h"
#include "sal/types.h"

namespace {

class Id {
public:
    Id() { rtl_createUuid(uuid_, nullptr, false); }

    Id(const Id&) = delete;
    Id& operator=(const Id&) = delete;

    void copy(sal_uInt8 * target) const
    { std::memcpy(target, uuid_, UUID_SIZE); }

private:
    enum { UUID_SIZE = 16 };

    sal_uInt8 uuid_[UUID_SIZE];
};

struct theId: public rtl::Static< Id, theId > {};

}

void rtl_getGlobalProcessId(sal_uInt8 * pTargetUUID) {
    theId::get().copy(pTargetUUID);
}

/* vim:set shiftwidth=4 softtabstop=4 expandtab: */

==> libreoffice_6.2.8.orig.tar.xz: libreoffice-6.2.8/sal/rtl/rtl_process.cxx <==
/* -*- Mode: C++; tab-width: 4; indent-tabs-mode: nil; c-basic-offset: 4 -*- */
/*
 * This file is part of the LibreOffice project.
 *
 * This Source Code Form is subject to the terms of the Mozilla Public
 * License, v. 2.0. If a copy of the MPL was not distributed with this
 * file, You can obtain one at http://mozilla.org/MPL/2.0/.
 *
 * This file incorporates work covered by the following license notice:
 *
 *   Licensed to the Apache Software Foundation (ASF) under one or more
 *   contributor license agreements. See the NOTICE file distributed
 *   with this work for additional information regarding copyright
 *   ownership. The ASF licenses this file to you under the Apache
 *   License, Version 2.0 (the "License"); you may not use this file
 *   except in compliance with the License. You may obtain a copy of
 *   the License at http://www.apache.org/licenses/LICENSE-2.0 .
 */

#include <sal/config.h>

#include <cstring>

#include <rtl/instance.hxx>
#include <rtl/process.h>
#include <rtl/uuid.h>
#include <sal/types.h>

namespace
{

class Id
{
public:
    Id() { rtl_createUuid(uuid_, nullptr, false); }

    Id(const Id&) = delete;
    Id& operator=(const Id&) = delete;

    void copy(sal_uInt8 * target) const
        { std::memcpy(target, uuid_, UUID_SIZE); }

private:
    enum { UUID_SIZE = 16 };

    sal_uInt8 uuid_[UUID_SIZE];
};

struct theId: public rtl::Static< Id, theId > {};

} // end namespace

void rtl_getGlobalProcessId(sal_uInt8 * pTargetUUID)
{
    theId::get().copy(pTargetUUID);
}

/* vim:set shiftwidth=4 softtabstop=4 expandtab: */
